checkRequire("Lua_PeakDuelRolePanel")
checkRequire("Lua_ChampionshipChatItem")
Lua_PeakDuelGuessPanel = class("Lua_PeakDuelGuessPanel", Lua_DisplayObject)
function Lua_PeakDuelGuessPanel:ctor(p)
	self:superCall("ctor", p, "PeakDuelGuessPanel_skin")
end

function Lua_PeakDuelGuessPanel:buildShowItem()
	self:superCall("buildShowItem")
	self.bFirstEnter = true

	self:addLuaEvent("ADD_CHAT_MSG", self, self.onChatUpdate)
	self:addLuaEvent("CHAT_STATIC_EMOJI_SELECT", self, self.onStaticEmojiSelected)
	self:addLuaEvent("CHAT_DYNAMIC_EMOJI_SELECT", self, self.onDynamicEmojiSelected)

	self:addLuaEvent("PEAK_DUEL_GUESS_INFO", self, self.showGuessInfo)
	self:addLuaEvent("PEAK_DUEL_GUESS_NUM", self, self.updateGuessNum)

	self.bg_1:SetDimensions(720, 994 + self.adaptHeight)
	self.showObject:SetActive(false)
	self.leftQuiz:addClickFuntion(self, self.onLeftGuess)
	self.rightQuiz:addClickFuntion(self, self.onRightGuess)
	self.checkRecord:addClickFuntion(self, self.onCheckRecord)

	self.chatChannel = Lua_ChatData.CHANNEL_PEAKDUEL
	self.defaultText = LanUtil.getValue(540053)
	self.curInputLen = 0
	self.sendLimit = Lua_ChatChannelData.getConfigDataById(self.chatChannel).num_limit

	self.chatContainer = Lua_DragContainer.new(self.content, 720, 490 + self.adaptHeight, Lua_AxisDefine.Vertical, true)
	self.chatContainer:setSiblingIndex(2)
	self.chatContainer:setLocation(0, -247.5, 0)

	self.chatInput:setDefaultLangValue(540053)
	self.chatInput.text = nil
	self.chatInput:onChange(self, self.onInputChange)
	self.btnEmoji:addClickFuntion(self, self.onEmojiClick)
	self.btnSend:addClickFuntion(self, self.onSendClick)
	
	DataCenter.chatData:setChannelNewMsgNum(self.chatChannel, 0)
	local arr = DataCenter.chatData:getChannelMsgList(self.chatChannel)
	self:updateChatList(arr)

	self:onRequestInfo()
end

function Lua_PeakDuelGuessPanel:dispose()
	if self.chatContainer then
		self.chatContainer:dispose()
		self.chatContainer = nil
	end
	if self.rolePanel then
		self.rolePanel:dispose()
		self.rolePanel = nil
	end
	if self.btnList then
		self.btnList:dispose()
		self.btnList = nil
	end
	if self.btnInfo then
		self.btnInfo:clear()
		self.btnInfo = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_PeakDuelGuessPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight)
	self.bg_1:SetDimensions(720, 994 + adaptHeight)
	self.chatContainer:setContentRect(720, 490 + adaptHeight)
end

function Lua_PeakDuelGuessPanel:showTips(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/championship/xui_jys_widget_18.png", 14.5, -304, 0, 0)
			self.noneIcon.anchorValue = 1

			self.noneText = UICreate.createLabel(self.content, nil, 7.5, -355, 100, 31, 32)
			self.noneText.anchorValue = 1
			self.noneText.pivotValue = 4
			self.noneText.fontName = Lua_MyUISettings.huakangFontName
			self.noneText.alignmentValue = 4
			self.noneText.horizontalOverflowValue = 1
			self.noneText.verticalOverflowValue = 1
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("7A6C74")
			self.noneText:setLangValue(540047)
		end
		self.noneIcon:setEnable(true)
		self.noneText:setEnable(true)
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false)
			self.noneText:setEnable(false)
		end
	end
end

function Lua_PeakDuelGuessPanel:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuess()
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuessNum()
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuessResult()
end

function Lua_PeakDuelGuessPanel:updateChatList(chatList)
	self.chatContainer:clearList()
	local len = chatList:getSize()
	for i = 1, len do
		self.chatContainer:addSubContainer(Lua_ChampionshipChatItem, chatList[i])
	end
	self.chatContainer:updateChildPos()
	self.chatContainer:moveToIndex(len, true)
end

function Lua_PeakDuelGuessPanel:onInputChange()
	local str = self.chatInput.text
	local len = Lua_ChatUtil.calcInputTextLen(str)
	local validLen = len > self.sendLimit and self.curInputLen or len
	if len > self.sendLimit then
		self.chatInput.text = self.prevTextContent
	else
		self.curInputLen = validLen
		self.prevTextContent = str
	end
end

function Lua_PeakDuelGuessPanel:onChatUpdate(chatVo)
	if chatVo == nil or chatVo.channel ~= self.chatChannel then
		return
	end

	local chatLimit = Lua_ChatChannelData.getConfigDataById(self.chatChannel).msg_limit
	local chatLen = self.chatContainer.showDragDataList:getSize()
	if chatLen >= chatLimit then
		self.chatContainer:clearList()
		local arr = DataCenter.chatData:getChannelMsgList(self.chatChannel)
		for i = 1, arr:getSize() do
			self.chatContainer:addSubContainer(Lua_ChampionshipChatItem, arr[i], false)
		end
		self.chatContainer:updateChildPos()
	else
		self.chatContainer:addSubContainer(Lua_ChampionshipChatItem, chatVo, true)
	end
	self.chatContainer:moveToIndex(chatLen, true)
end

function Lua_PeakDuelGuessPanel:onStaticEmojiSelected(emojiId)
	local str = self.chatInput.text
	if str == self.defaultText then
		str = LanUtil.formateStr(10044, "", tostring(emojiId))
	else
		str = LanUtil.formateStr(10044, str, tostring(emojiId))
	end
	if Lua_ChatUtil.calcInputTextLen(str) <= self.sendLimit then
		self.chatInput.text = str
	else
		OperateAlert.showLangValue(171043)
	end
end

function Lua_PeakDuelGuessPanel:onDynamicEmojiSelected(emojiId)
	DataCenter.chatData:setChatShowItem(Lua_ChatData.CONTENT_DYNANIC_EMOJI, emojiId)
	Lua_ChatUtil.sendMsg(self.chatChannel, emojiId, false, false)
end

function Lua_PeakDuelGuessPanel:onEmojiClick(go)
	Lua_WindowUtil.openWin("Lua_ChatEmojiWindow", Lua_WinParam.ACTION_OPEN,{ pos = {58, -345 - self.adaptHeight / 2} })
end

function Lua_PeakDuelGuessPanel:onSendClick(go)
	local str = self.chatInput.text
	if str == self.defaultText or utf8len(str) <= 0 then
		OperateAlert.showLangValue(171023)
		return
	end
	Lua_ChatUtil.sendMsg(self.chatChannel, str, true, true)
	self.chatInput.text = nil
end

function Lua_PeakDuelGuessPanel:showGuessInfo(msg)
	self.data = msg
	self.left_support_times = msg.left_support_times
	self.bet_id = tonumber(msg.bet_id)

	if msg.is_have_guess == 1 then
		self:showTips(false)
		self.bg_2:setLocation(0, -562, 0)
		self.line_1:setEnable(true)
		self.showObject:SetActive(true)

		if self.rolePanel == nil then
			self.rolePanel = Lua_PeakDuelRolePanel.new(self.showObject)
			self.rolePanel:setRectAnchor(1)
			self.rolePanel:setLocation(0, -322, 0)
			self.rolePanel:setCallBack(self, self.onRequestInfo)
		end
		self.rolePanel:setStageInfo(msg.guess_stage_info, msg.record_id)

		local serverTime = DataCenter.roleData.serverTime
		if self.bFirstEnter ~= true and serverTime < tonumber(msg.guess_stage_info.match_end_tick) then -- 比赛阶段
			Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(msg.record_id, 0, "", 0, 3);
			Lua_WindowUtil.openWin("Lua_PeakDuelGuessSelectWindow", Lua_WinParam.ACTION_CLOSE)
		end

		local att_lineup = msg.attack_role.lineup
		local def_lineup = msg.defence_role.lineup
		local len = #att_lineup > #def_lineup and #att_lineup or #def_lineup
		if len > 1 then
			self.promptText:setEnable(false)
			if self.btnInfo == nil then
				self.btnInfo = Array()
				for i = 1, len do
					self.btnInfo:add({ textStr = LanUtil.formateStr(202976, convert_arab_to_chinese(i)) })
				end

				self.btnList = Lua_ButtonList.new(self.showObject, Lua_AxisDefine.Horizontal)
				self.btnList:setRectAnchor(1)
				self.btnList:setLocation(0, -530, 0)
				self.btnList:setButtonStyle("peak_duel_altas", "xui_dfs_widget_11", "xui_dfs_button_6", 182, 48)
				self.btnList:setButtonText(0, 0, "DCD6D6", "8F5123", 28, 28, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal)
				self.btnList:setButtonItem(182, 48)
				self.btnList:setClickCallBack(self, self.onButtonClick)
				self.btnList:setData(self.btnInfo)
				self.btnList:setSelected(1)
			end
		else
			self.promptText:setEnable(true)
			if self.btnList then
				self.btnList:setEnable(false)
			end
			self.rolePanel:setRoleInfo(msg.attack_role, msg.defence_role, msg.win_id, 1)
		end

		self:updateQuizTimes()
		self:updateQuizState()
		self:updateQuizNum(msg.attack_role_num, msg.defence_role_num)
	else
		self:showTips(true)
		self.bg_2:setLocation(0, -710, 0)
		self.line_1:setEnable(false)
		self.showObject:SetActive(false)
	end

	self.bFirstEnter = false
end

function Lua_PeakDuelGuessPanel:onButtonClick(index, data)
	self.rolePanel:setRoleInfo(self.data.attack_role, self.data.defence_role, self.data.win_id, index)
end

function Lua_PeakDuelGuessPanel:updateGuessNum(msg)
	if msg.left_support_times then
		self.left_support_times = msg.left_support_times
	end
	if msg.bet_id then
		self.bet_id = tonumber(msg.bet_id)
	end
	self:updateQuizTimes()
	self:updateQuizState()
	self:updateQuizNum(msg.attack_role_num, msg.defence_role_num)
end

function Lua_PeakDuelGuessPanel:updateQuizState()
	if self.bet_id > 0 then
		self.leftQuiz.mouseEnable = false
		self.rightQuiz.mouseEnable = false
		if self.bet_id == 1 then
			self.leftQuiz:setGray(false)
			self.rightQuiz:setGray(true)
			self.leftQuizText:setLangValue(202993)
			self.rightQuizText:setLangValue(202992)
		else
			self.leftQuiz:setGray(true)
			self.rightQuiz:setGray(false)
			self.leftQuizText:setLangValue(202992)
			self.rightQuizText:setLangValue(202993)
		end
	else
		self.leftQuizText:setLangValue(202992)
		self.rightQuizText:setLangValue(202992)
		local serverTime = DataCenter.roleData.serverTime
		local info = self.data.guess_stage_info
		if serverTime < tonumber(info.interaction_end_tick) then -- 互动阶段
			self.leftQuiz.mouseEnable = true
			self.leftQuiz:setGray(false)
			self.rightQuiz.mouseEnable = true
			self.rightQuiz:setGray(false)
		else
			self.leftQuiz.mouseEnable = false
			self.leftQuiz:setGray(true)
			self.rightQuiz.mouseEnable = false
			self.rightQuiz:setGray(true)
		end
	end
end

function Lua_PeakDuelGuessPanel:updateQuizTimes()
	local total_times = DataCenter.peakDuelUtil.daily_guess_times
	self.guessText.text = LanUtil.formateStr(202980, self.left_support_times, tostring(total_times))
end

function Lua_PeakDuelGuessPanel:updateQuizNum(bet_att_nums, bet_def_nums)
	self.leftRate.text = LanUtil.formateStr(202979, tostring(bet_att_nums))
	self.rightRate.text = LanUtil.formateStr(202979, tostring(bet_def_nums))

	local width = self.barBg.width
	local addH = 10
	local temp = width / 2 + addH
	if bet_att_nums == bet_def_nums then
		self.leftBar:SetDimensions(temp, 24)
		self.rightBar:SetDimensions(temp, 24)
		self.barText:setLangValue(540050)
	else
		-- print(bet_att_nums, bet_def_nums)
		local maxValue = bet_att_nums + bet_def_nums
		local value
		if bet_att_nums == 0 then
			self.leftBar:SetDimensions(0, 24)
			self.rightBar:SetDimensions(width, 24)
		elseif bet_def_nums == 0 then
			self.leftBar:SetDimensions(width, 24)
			self.rightBar:SetDimensions(0, 24)
		else
			local leftIdx = self.leftBar.siblingIndex
			local rightIdx = self.rightBar.siblingIndex
			if bet_att_nums > bet_def_nums then
				value = bet_att_nums / maxValue
				temp = width * value
				self.leftBar:SetDimensions(temp + addH, 24)
				self.leftBar.siblingIndex = rightIdx
				self.rightBar:SetDimensions(width - temp + addH, 24)
				self.rightBar.siblingIndex = leftIdx
			else
				value = bet_def_nums / maxValue
				temp = width * value
				self.leftBar:SetDimensions(width - temp + addH, 24)
				self.rightBar:SetDimensions(temp + addH, 24)
				if leftIdx > rightIdx then
					self.leftBar.siblingIndex = rightIdx
					self.rightBar.siblingIndex = leftIdx
				end
			end
		end
		if bet_att_nums > bet_def_nums then
			value = string.format("%.1f", bet_att_nums / maxValue)
		else
			value = string.format("%.1f", bet_def_nums / maxValue)
		end
		self.barText.text = LanUtil.formateStr(10053, tostring(tonumber(value * 100)));
	end
end

function Lua_PeakDuelGuessPanel:onCheckRecord(go)
	Lua_WindowUtil.openWin("Lua_PeakDuelGuessRecordWindow", Lua_WinParam.ACTION_OPEN)
end

function Lua_PeakDuelGuessPanel:onLeftGuess(go)
	if self.left_support_times <= 0 then
		OperateAlert.showLangValue(202977)
		return
	end
	if self.bet_id > 0 then
		OperateAlert.showLangValue(202978)
		return
	end
	Lua_WindowUtil.openWin("Lua_PeakDuelGuessSelectWindow", Lua_WinParam.ACTION_OPEN, { bet_id = 1, name = self.data.attack_role.show_role.name })
end

function Lua_PeakDuelGuessPanel:onRightGuess(go)
	if self.left_support_times <= 0 then
		OperateAlert.showLangValue(202977)
		return
	end
	if self.bet_id > 0 then
		OperateAlert.showLangValue(202978)
		return
	end
	Lua_WindowUtil.openWin("Lua_PeakDuelGuessSelectWindow", Lua_WinParam.ACTION_OPEN, { bet_id = 2, name = self.data.defence_role.show_role.name })
end