Lua_PeakDuelRankPanel = class("Lua_PeakDuelRankPanel", Lua_DisplayObject)
function Lua_PeakDuelRankPanel:ctor(p)
	self:superCall("ctor", p, "PeakDuelRankPanel_skin")
end

function Lua_PeakDuelRankPanel:buildShowItem()
	self:superCall("buildShowItem")
	self.topPos = {{2, -366}, {-235, -366}, {236, -366}}
	self.topArr = Array()
	self.rankArr = Array()
	self.maxTimesIdx = 1
	self.curTimesIdx = self.maxTimesIdx

	self:addLuaEvent("PEAK_DUEL_RANK_SEASON", self, self.onSeasonInfo)
	self:addLuaEvent("PEAK_DUEL_RANK_INFO", self, self.onRankInfo)
	self:addLuaEvent("PEAK_DUEL_RANK_UPDATE", self, self.updateRankInfo)
	self:addLuaEvent("PEAK_DUEL_RANK_LIKE", self, self.onLike)
	self:addLuaEvent("PEAK_DUEL_DIVISION_SELECT", self, self.onDivisionSelect)

	local item
	for i = 1, 3 do
		item = Lua_PeakDuelRankTopItem.new(self.content)
		item.contentName = "topRank_"..i
		item:setRectAnchor(1)
		item:setLocation(self.topPos[i][1], self.topPos[i][2], 0)
		item:setRank(i)
		self.topArr:add(item)
	end

	self.myAvatarItem = Lua_AvatarItem.new(self.content)
	self.myAvatarItem:setRectAnchor(7)
	self.myAvatarItem:setScale(0.7, 0.7, 1)
	self.myAvatarItem:setLocation(-147, 256, 0)

	self.rankList = Lua_DragList.new(self.content, 688, 470 + self.adaptHeight, Lua_AxisDefine.Vertical)
	self.rankList:setLocation(0, -140, 0)
	self.rankList.tweenId = 2008
	self.rankList.delayTween = true
	self.rankList.callBackOwner = self
	self.rankList.turnPageCallBack = self.turePage
	self.rankList:setListCell(Lua_PeakDuelRankItem, 688, 125, 1)
	self.rankList:setCellSpacing(0, 5)

	self.btnInfo = Array()
	self.btnInfo:add(202964)
	self.btnInfo:add(202965)

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal)
	self.buttonList:setRectAnchor(7)
	self.buttonList:setLocation(0, 154, 0)
	self.buttonList:setButtonCell(Lua_CommonButtonItem2)
	self.buttonList:setButtonItem(160, 67)
	self.buttonList:setClickCallBack(self, self.onButtonClick)
	self.buttonList:setData(self.btnInfo)
	self.buttonList:setSelected(1)

	self.listBg:SetDimensions(720, 500 + self.adaptHeight)
	self.btnLeft:addClickFuntion(self, self.onLeftClick)
	self.btnRight:addClickFuntion(self, self.onRightClick)
	self.checkDivision:addClickFuntion(self, self.onCheckDivision)
end

function Lua_PeakDuelRankPanel:dispose()
	if self.topArr then
		self.topArr:dispose()
		self.topArr:clear()
		self.topArr = nil
	end
	if self.btnList then
		self.btnList:dispose()
		self.btnList = nil
	end
	if self.btnInfo then
		self.btnInfo:clear()
		self.btnInfo = nil
	end
	if self.rankList then
		self.rankList:dispose()
		self.rankList = nil
	end
	if self.rankArr then
		self.rankArr:clear()
		self.rankArr = nil
	end
	if self._myRankNum then
		self._myRankNum:dispose()
		self._myRankNum = nil
	end
	if self.myAvatarItem then
		self.myAvatarItem:dispose()
		self.myAvatarItem = nil
	end
	DataCenter.winTweenManager:removeWinTween(self.tweenName)
	self.tweenName = nil
	self:superCall("dispose")
end

function Lua_PeakDuelRankPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight)
	self.listBg:SetDimensions(720, 500 + adaptHeight)
	self.rankList:setContentRect(688, 470 + adaptHeight)
end

function Lua_PeakDuelRankPanel.Get:myRankNum()
	if self._myRankNum == nil then
		self._myRankNum = Lua_NumberImage.new(self.content)
		self._myRankNum:setRectAnchor(7)
		self._myRankNum:setLocation(-270.5, 256, 0)
		self._myRankNum.numOffsetX = -4
		self._myRankNum.numAtlas = "number"
		self._myRankNum.preStr = "xui_phb_number_"
	end
	self._myRankNum:setEnable(true)
	return self._myRankNum
end

function Lua_PeakDuelRankPanel:onButtonClick(index)
	self.selectedIdx = index
	self.btnLeft:setEnable(index == 1)
	self.btnRight:setEnable(index == 1)
	self.checkDivision:setEnable(index == 1)
	self:initList()
	if index == 1 then
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sSeason(DataCenter.peakDuelData.region_id)
	else
		self.region_id = 0
		self.times = DataCenter.peakDuelData.times
		self.region_name = DataCenter.peakDuelData.region_name
		self:turePage(0)
	end
end

function Lua_PeakDuelRankPanel:initList()
	self.bRefresh = true
	self.rankList.showTween = true
	self.rankList.isPageEnd = false

	local item
	for i = 1, 3 do
		item = self.topArr[i]
		if item then
			item:setEnable(false)
			item:setLocation(self.topPos[i][1], self.topPos[i][2], 0)
		end
	end
end

function Lua_PeakDuelRankPanel:turePage(page)
	self.page = page or 1
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(self.region_id, self.times, self.page)
end

function Lua_PeakDuelRankPanel:onSeasonInfo(msg)
	if msg == nil then
		return
	end

	self.region_id = tonumber(msg.region_id)
	self.region_name = msg.region_name
	self.times_list = msg.times_list

	self.maxTimesIdx = #self.times_list
	self.curTimesIdx = self.maxTimesIdx

	self.times = self.times_list[self.curTimesIdx]
	self.nameText.text = LanUtil.formateStr(202966, tostring(self.times), self.region_name)

	self:initList()
	self:turePage(0)
end

function Lua_PeakDuelRankPanel:onRankInfo(msg)
	if self.bRefresh then
		local len = self.rankArr:getSize()
		local num = len - #msg.role_list
		while (num > 0) do
			self.rankArr:remove()
			num = num - 1
		end
		for i = 1, #msg.role_list do
			if i > len then
				self.rankArr:add(msg.role_list[i])
			else
				self.rankArr[i] = msg.role_list[i]
			end
		end
	else
		for i = 1, #msg.role_list do
			self.rankArr:add(msg.role_list[i])
		end
	end
	self.rankList.isPageEnd = (msg.is_end == 1)

	local info = msg.self_rank
	if info == nil then
		self.myNoneRankSp:setEnable(true)
		self.myNameTxt:setEnable(false)
		self.myLeagueTxt:setEnable(false)
		self.myValueTxt:setEnable(false)
		if self._myRankNum then self._myRankNum:setEnable(false) end
		self.myAvatarItem:init()
	else
		if info.rank < 1 then
			self.myNoneRankSp:setEnable(true)
			if self._myRankNum then self._myRankNum:setEnable(false) end
		else
			self.myNoneRankSp:setEnable(false)
			self.myRankNum.num = info.rank
		end
		self.myNameTxt:setEnable(true)
		self.myLeagueTxt:setEnable(true)
		self.myValueTxt:setEnable(true)

		self.myNameTxt.text = info.show_role.name
		self.myAvatarItem:setRoleId(info.role_id)
		self.myAvatarItem:setRoleDressUp(info.show_role.dress_info, true)
		self.myAvatarItem:setRoleLevel2(info.show_role.level)

		local config = DataCenter.peakDuelUtil:getSegmentInfoByid(info.segment_lvl)
		self.myValueTxt.text = LanUtil.formateStr(10058, config.name, info.score)

		self.myLikeNumTxt.text = info.praise_num
		if strIsNullOrEmpty(info.show_role.league_name) then
			self.myLeagueTxt:setLangValue(202503)
		else
			self.myLeagueTxt.text = LanUtil.formateStr(202504, info.show_role.league_name)
		end
	end

	self:updateRankList()
	self:updateLikeTimes()
end

function Lua_PeakDuelRankPanel:updateLikeTimes()
	local total_like_times = DataCenter.peakDuelUtil.daily_praise_num
	local left_times = DataCenter.peakDuelData.left_praise_times
	self.likeNumText.text = LanUtil.formateStr(202967, tostring(left_times), tostring(total_like_times))
end

function Lua_PeakDuelRankPanel:updateRankInfo(msg)
	for i = 1, self.rankArr:getSize() do
		if self.rankArr[i].role_id == msg.role_info.role_id then
			self.rankArr[i] = msg.role_info
			break
		end
	end
	self:updateRankList()
	self:updateLikeTimes()
end

function Lua_PeakDuelRankPanel:updateRankList()
	local len = self.rankArr:getSize() - 3
	if len > 0 then
		self.rankList:setEnable(true)
		self.rankList:setArrayData(self.rankArr, 4)
		if self.bRefresh then
			self.rankList:moveToIndex(1, true)
		end
		self:showNone(false)
	else
		self.rankList:setEnable(false)
		self:showNone(true)
	end
	self:updateTopRank()
	self.bRefresh = false
end

function Lua_PeakDuelRankPanel:updateTopRank()
	for i = 1, 3 do
		self.topArr[i]:setData(i, self.rankArr[i])
	end
	self:updateTween()
end

function Lua_PeakDuelRankPanel:updateTween()
	if not self.bRefresh then
		return
	end
	
	if self.tweenName then
		DataCenter.winTweenManager:removeWinTween(self.tweenName)
	end
	self.tweenName = DataCenter.winTweenManager:createWinTween(self.content.name, self.content.transform)
end

function Lua_PeakDuelRankPanel:showNone(value)
	if value then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/championship/xui_jys_widget_18.png", 0, -170, 0, 0)

			self.noneText = UICreate.createLabel(self.content, nil, 1.5, -220, 100, 40, 36)
			self.noneText.pivotValue = 4
			self.noneText.fontName = Lua_MyUISettings.huakangFontName
			self.noneText.alignmentValue = 4
			self.noneText.horizontalOverflowValue = 1
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("7A6C74")
			self.noneText:setLangValue(202502)
		end
		self.noneIcon:setEnable(true)
		self.noneText:setEnable(true)
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false)
			self.noneText:setEnable(false)
		end
	end
end

function Lua_PeakDuelRankPanel:onLike(data)
	if self.selectedIdx == 1 then
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDLike(data.role_id, self.region_id, self.times, data.score)
	else
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDLike(data.role_id, 0, self.times, data.score)
	end
end

function Lua_PeakDuelRankPanel:onDivisionSelect(data)
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sSeason(data)
end

function Lua_PeakDuelRankPanel:onLeftClick(go)
	if self.curTimesIdx <= 1 then
		OperateAlert.showLangValue(202948)
		return
	end
	self.curTimesIdx = self.curTimesIdx - 1

	self.times = self.times_list[self.curTimesIdx]
	self.nameText.text = LanUtil.formateStr(202966, tostring(self.times), self.region_name)

	self:initList()
	self:turePage(0)
end

function Lua_PeakDuelRankPanel:onRightClick(go)
	if self.curTimesIdx >= self.maxTimesIdx then
		OperateAlert.showLangValue(202948)
		return
	end
	self.curTimesIdx = self.curTimesIdx + 1

	self.times = self.times_list[self.curTimesIdx]
	self.nameText.text = LanUtil.formateStr(202966, tostring(self.times), self.region_name)

	self:initList()
	self:turePage(0)
end

function Lua_PeakDuelRankPanel:onCheckDivision(go)
	Lua_WindowUtil.openWin("Lua_PeakDuelDivisionWindow", Lua_WinParam.ACTION_OPEN)
end



















Lua_PeakDuelRankTopItem = class("Lua_PeakDuelRankTopItem", Lua_DisplayObject)
function Lua_PeakDuelRankTopItem:ctor(p)
	self:superCall("ctor", p, "PeakDuelRankTopItem_skin")
	self.avatarItem = Lua_AvatarItem.new(self.content)

	self.btnLike:addClickFuntion(self, self.onLikeClick)
end

function Lua_PeakDuelRankTopItem:buildShowItem()
	self:superCall("buildShowItem")
end

function Lua_PeakDuelRankTopItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_PeakDuelRankTopItem:setRank(value)
	self.bg:setAltas("rank_altas", "xui_phb_bg_"..(value + 1))
	self.rankText.text = LanUtil.formateStr(202538, convert_arab_to_chinese(value))
	if value == 1 then
		self.rankText:setLocation(0, 25, 0)
		self.rankText.fontSize = 30
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FCF6AF")

		self.nameText:setLocation(0, -19.5, 0)
		self.nameText.fontSize = 30
		self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")

		self.leagueText:setLocation(0, -48.5, 0)
		self.leagueText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")

		self.lvIcon:setLocation(-5, -76, 0)
		self.valueText:setLocation(5, -76, 0)
		self.valueText.colorStr = Lua_ColorDefine.transColor("FFFFFF")
		self.valueText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")

		self.btnLike:setLocation(0, -109.5, 0)
		self.likeNumText:setLocation(-20.5, -106, 0)

		self.avatarItem:setScale(0.9, 0.9, 1)
		self.avatarItem:setLocation(0, 108, 0)
	else
		self.rankText:setLocation(0, 28, 0)
		self.rankText.fontSize = 26
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")

		self.nameText:setLocation(0, -5, 0)
		self.nameText.fontSize = 26

		self.leagueText:setLocation(0, -33.5, 0)
		
		self.lvIcon:setLocation(-5, -58, 0)
		self.valueText:setLocation(5, -58, 0)
		self.valueText.colorStr = Lua_ColorDefine.transColor("FFFFFF")

		self.btnLike:setLocation(0, -90.5, 0)
		self.likeNumText:setLocation(-20.5, -87.5, 0)

		if value == 2 then
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("606A93")
			self.leagueText.effectColorStr = Lua_ColorDefine.transColorStr("606A93")
			self.valueText.effectColorStr = Lua_ColorDefine.transColorStr("606A93")
			self.likeNumText.effectColorStr = Lua_ColorDefine.transColorStr("606A93")
		else
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")
			self.leagueText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")
			self.valueText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")
			self.likeNumText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A")
		end

		self.avatarItem:setScale(0.8, 0.8, 1)
		self.avatarItem:setLocation(0, 96, 0)
	end
end

function Lua_PeakDuelRankTopItem:setData(rank, data)
	self.data = data
	if data == nil then
		self.nameText:setLangValue(202500)
		self.leagueText:setEnable(false)
		self.lvIcon:setEnable(false)
		self.valueText:setEnable(false)
		self.likeNumText:setEnable(false)
		self.avatarItem:init()
		self:showRedPoint(false)
	else
		self.nameText.text = data.show_role.name

		self.leagueText:setEnable(true)
		if strIsNullOrEmpty(data.show_role.league_name) then
			self.leagueText:setLangValue(202503)
		else
			self.leagueText.text = LanUtil.formateStr(202504, data.show_role.league_name)
		end

		local config = DataCenter.peakDuelUtil:getSegmentInfoByid(data.segment_lvl)
		self.lvIcon:setEnable(true)
		self.lvIcon:setAltas("peak_duel_altas", config.icon)

		self.valueText:setEnable(true)
		self.valueText.text = data.score
		self.valueText:resetSize()

		local width = (self.valueText.width + 25) / 2
		if rank == 1 then
			self.lvIcon:setLocation(-width - 5, -74, 0)
			self.valueText:setLocation(self.lvIcon.posX + 30, -76, 0)
		else
			self.lvIcon:setLocation(-width - 5, -56, 0)
			self.valueText:setLocation(self.lvIcon.posX + 30, -58, 0)
		end

		self.likeNumText:setEnable(true)
		self.likeNumText.text = data.praise_num

		self.avatarItem:setEnable(true)
		self.avatarItem:setRoleId(data.show_role.id, data.show_role.server_flag, data.is_robot)
		self.avatarItem:setRoleDressUp(data.show_role.dress_info, true)
		self.avatarItem:setRoleLevel2(data.show_role.level)

		if DataCenter.roleData:isMyself(data.show_role.id) then
			self:showRedPoint(false)
		else
			self:showRedPoint(data.is_praised == 0 and DataCenter.peakDuelData.left_praise_times > 0, rank)
		end
	end
end

function Lua_PeakDuelRankTopItem:showRedPoint(value, rank)
	if value then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:createRedPointImg()
		end
		if rank == 1 then
			self.redPoint:setLocation(52, -97)
		else
			self.redPoint:setLocation(52, -78)
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_PeakDuelRankTopItem:onLikeClick(go)
	if self.data == nil then
		return
	end
	if DataCenter.roleData:isMyself(self.data.role_id) then
		OperateAlert.showLangValue(202970)
		return
	end
	if DataCenter.peakDuelData.left_praise_times <= 0 then
		OperateAlert.showLangValue(202968)
		return
	end
	if self.data.is_praised == 1 then
		OperateAlert.showLangValue(202969)
		return
	end
	Lua_MsgUtil.callFunc("PEAK_DUEL_RANK_LIKE", self.data)
end




















Lua_PeakDuelRankItem = class("Lua_PeakDuelRankItem", Lua_ListCell)
function Lua_PeakDuelRankItem:ctor(p)
	self:superCall("ctor", p, "PeakDuelRankItem_skin")
end

function Lua_PeakDuelRankItem:buildShowItem()
	self:superCall("buildShowItem")
	self.btnLike:addClickFuntion(self, self.onLikeClick)

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.7, 0.7, 1)
	self.avatarItem:setLocation(-147, 0, 0)
end

function Lua_PeakDuelRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_PeakDuelRankItem:setData(data)
	self.data = data

	self.numTxt.text = data.rank
	
	self.avatarItem:setRoleId(data.role_id, data.show_role.server_flag, data.is_robot)
	self.avatarItem:setRoleDressUp(data.show_role.dress_info, true)
	self.avatarItem:setRoleLevel2(data.show_role.level)

	self.nameTxt.text = data.show_role.name
	if strIsNullOrEmpty(data.show_role.league_name) then
		self.leagueTxt:setLangValue(202503)
	else
		self.leagueTxt.text = LanUtil.formateStr(202504, data.show_role.league_name)
	end

	local config = DataCenter.peakDuelUtil:getSegmentInfoByid(data.segment_lvl)
	self.valueTxt.text = LanUtil.formateStr(10058, config.name, data.score)
	self.likeNumTxt.text = data.praise_num

	if data.is_praised == 1 then
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_p");
	else
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_n");
	end
end

function Lua_PeakDuelRankItem:onLikeClick(go)
	if self.data == nil then
		return
	end
	if DataCenter.roleData:isMyself(self.data.role_id) then
		OperateAlert.showLangValue(202970)
		return
	end
	if DataCenter.peakDuelData.left_praise_times <= 0 then
		OperateAlert.showLangValue(202968)
		return
	end
	if self.data.is_praised == 1 then
		OperateAlert.showLangValue(202969)
		return
	end
	Lua_MsgUtil.callFunc("PEAK_DUEL_RANK_LIKE", self.data)
end